import 'package:flutter/foundation.dart';

class ApiConfig {
  bool debugMode;
  Map<String, dynamic> defaultParameters;
  final bool encrypt;
  final String url;
  final String publicKey;
  final String androidSecretKey;
  final String iosSecretKey;
  final String webSecretKey;
  final Duration defaultTimeout;
  final Duration uploadTimeout;

  String get secretKey {
    if (kIsWeb) {
      return webSecretKey;
    } else {
      if (defaultTargetPlatform == TargetPlatform.android) {
        return androidSecretKey;
      } else {
        return iosSecretKey;
      }
    }
  }

  ApiConfig(
    this.url, {
    this.publicKey,
    this.androidSecretKey,
    this.iosSecretKey,
    this.webSecretKey,
    this.encrypt = false,
    this.defaultParameters,
    this.debugMode = false,
    this.defaultTimeout = const Duration(seconds: 60),
    this.uploadTimeout = const Duration(minutes: 5),
  })  : assert(url != null),
        assert(encrypt == false ||
            (encrypt && publicKey != null && androidSecretKey != null)) {
    if (defaultParameters == null) {
      defaultParameters = {};
    }
  }

  @override
  String toString() {
    return {
      'url': url,
      'encrypt': encrypt,
      'debugMode': debugMode,
      'publicKey': publicKey,
      'androidSecretKey': androidSecretKey,
      'iosSecretKey': iosSecretKey,
      'webSecretKey': webSecretKey,
      'defaultParameters': defaultParameters,
      'defaultTimeout': defaultTimeout.toString(),
      'uploadTimeout': uploadTimeout.toString(),
    }.toString();
  }
}
